# epic-storage

A small data storage library

#### Installation

`$ npm i epic-storage --save`

## Usage

```
const storage = new epicStorage({
    storageName: "my-storage",
    prefix: "prefix-"
});

try {
    storage.init().then(() => {
        //Add New Schema
        storage.addSchema("test").then(() => {
            //Add Single Item
            storage.addItem("status", "Success").then(() => {
                console.log("Added Successfully!");
            });
            //Add Multiple Item
            storage.addItems({
                foo: "bar",
                hello: "world",
                bla: "bla",
                test: "test"
            }).then(() => {
                console.log("Added Successfully!");
                //Remove Item
                storage.removeItems(["status", "foo"]).then(() => {
                    console.log("Successfully Removed!");
                });
            });
        });
    });
} catch (ex) {
    console.log(ex);
}
```

## Options

- _storageName_ - _string_ (Default 'storage') Any Name
- _rootDir_ - _string_ (Default 'Module root') | Where to put data.
- _prefix_ - _string_ (Default 'epic\_') | Any Prefix
- _logs_ - _boolean_ (Default False) | Set True if logs are required.

## Methods

- **_init: () => Promise<unknown>_** - **_Required_** Initializes the module.
- **_addSchema: (schemaName: string, use?: boolean) => Promise<unknown>_** - Create new schema.
- **_hasSchema: (schemaName: string) => boolean_** - Check if Schema Exists.
- **_listSchema: () => string[]_** - List all available Schema.
- **_useSchema: (schemaName: string) => this_** - Pick a Schema to work with.
- **_removeSchema: (schemaName?: string | undefined) => this_** - Remove any or current working schema.
- **_renameSchema: (newSchemaName: string, oldSchemaName?: string | undefined) => this_** - Rename Schema.
- **_clearSchema: (schema?: string | undefined, throwError?: boolean) => this_** - Clear data from any Schema.
- **_addItem: (key: string, value: string | object, schema?: string | undefined, throwError?: boolean) =>Promise<unknown>_** - Add new item to storage.
- **_addItems: (data: ITEMS, schema?: string | undefined, throwError?: boolean) => Promise<unknown>_** - Add multiple item to storage.
- **_getItem: (key: string, schema?: string | undefined, throwError?: boolean) => Promise<any>_** - Get Item.
- **_getAllItems: (schema?: string | undefined, throwError?: boolean) => Promise<unknown>_** - Get all Items from working Schema.
- **_removeItem: (key: string, schema?: string | undefined, throwError?: boolean) => Promise<unknown>_** - Remove an Item.
- **_removeItems: (keys: string[], schema?: string | undefined, throwError?: boolean) => Promise<unknown>_** - Remove multiple Items.
- **_hasItem: (key: string, schema?: string | undefined) => Promise<unknown>_** - Check Item (Also checks the Schema).
- **_destroy: (logs?: boolean) => this_** - **_Caution_** Delete all storage.
- **_logConfig: (fileName: string, directory: string) => this_** - Change Log configuration.
- **_clearLog: () => this_** - Clear Logs.
